/*!
 * load2files.js
 * author: Brent M. Dingle
 * last modified: 2015
 * Example script for simple image loading.
 *
 * Other javaScript files required for this to work:
 *       none
*/
 
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// theProgram (singleton) Object                            theProgram Object
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
var theProgram = 
{
    // ------------------------------------------------------------------------
    // Pseudo-constants
    // ------------------------------------------------------------------------
    SOURCE_IMG_CANVAS_ID: "sourceCanvas",     // canvas id used in html
    SRC2_IMG_CANVAS_ID:   "sourceCan2",       // canvas id used in html
    OUTPUT_IMG_CANVAS_ID: "outputCanvas",     // canvas id used in html
    
    // ------------------------------------------------------------------------
    // Variables
    // ------------------------------------------------------------------------
    width:          400,           // canvas width... likely will be reset
    height:         400,           // canvas height... likely will be reset
    xOffset:        5,
    yOffset:        5,
    
    dropArea:       null,
    oneData:        null,
    twoData:        null,
    
    destCanvas:     null,
    destCTX:        null,
    
    // ------------------------------------------------------------------------
    // Functions
    // ------------------------------------------------------------------------
    //                                                          Main
    // ------------------------------------------------------------------------
    Main: function() 
    {
        // Setup the listeners
        this.dropArea = document.getElementById('theDropArea');
        this.dropArea.addEventListener('dragover', this.onDragOver, false);
        this.dropArea.addEventListener('drop', this.onDropFileSelect, false);

        // Get handle on the OUTPUT destCanvas
        theProgram.destCanvas = document.getElementById(theProgram.OUTPUT_IMG_CANVAS_ID);
        theProgram.destCTX = theProgram.destCanvas.getContext('2d');
                
    },
    

    // ------------------------------------------------------------------------
    // ------------------------------------------------------------------------
    onDragOver: function(evt) 
    {
        evt.stopPropagation();
        evt.preventDefault();
        evt.dataTransfer.dropEffect = 'copy'; // Explicitly make this is a copy
    },

    // ------------------------------------------------------------------------
    // ------------------------------------------------------------------------
    onDropFileSelect: function (evt) 
    {
        evt.stopPropagation();
        evt.preventDefault();
        var files = evt.dataTransfer.files; // files that were dragged 

        // If the "first" file is not an image, do nothing
        var curFile = files[0];
        // Only process image file
        if ( curFile.type.match('image.*') ) 
        {
            var imgOne = new Image;
            imgOne.onload = function() 
            {
                //theProgram.dropArea.style.display = "none"; unrem to allow only 1 drop of files
                var canvas = document.getElementById(theProgram.SOURCE_IMG_CANVAS_ID);
                var ctx = canvas.getContext('2d');
                canvas.style.display = "block";
                canvas.width = imgOne.width;  // world coordinate system size
                canvas.height = imgOne.height;
                canvas.style.width = canvas.width + "px" ;  // viewport coordinate system size (like TV screen)
                canvas.style.height = canvas.height + "px";
                ctx.drawImage(imgOne, 0, 0);
                //alert('the original image is drawn');   // for DEBUG
                
                // Set the source data BEFORE applying any filters!
                theProgram.oneData  = ctx.getImageData(0, 0, imgOne.width, imgOne.height);
                
                URL.revokeObjectURL(imgOne.src);  // clear up memory... may want to hold on this if doing "real" stuff
            }
            imgOne.src = URL.createObjectURL(curFile);
            
			// If the "second" file is not an image, do nothing for it
			var twoFile = files[1];
			if ( twoFile.type.match('image.*') ) 
			{
				var imgTwo = new Image;
				imgTwo.onload = function() 
				{
					var canvas2 = document.getElementById(theProgram.SRC2_IMG_CANVAS_ID);
					var ctx2 = canvas2.getContext('2d');
					canvas2.style.display = "block";
					canvas2.width = imgTwo.width;  // world coordinate system size
					canvas2.height = imgTwo.height;
					canvas2.style.width = canvas2.width + "px" ;  // viewport coordinate system size (like TV screen)
					canvas2.style.height = canvas2.height + "px";
					ctx2.drawImage(imgTwo, 0, 0);
					//alert('the original image is drawn');   // for DEBUG
					
					// Set the source data BEFORE applying any filters!
					theProgram.oneData  = ctx2.getImageData(0, 0, imgTwo.width, imgTwo.height);
					
					URL.revokeObjectURL(imgTwo.src);  // clear up memory... may want to hold on this if doing "real" stuff
				}
				imgTwo.src = URL.createObjectURL(twoFile);
            }
            
        } 
        // else first file type is NOT image --> so do nothing
    },
    
    // ------------------------------------------------------------------------
    // this function is not called, but left for reference
    // ------------------------------------------------------------------------
    displayOutput: function(destData)
    {
        // make things visible and correct size
        theProgram.destCanvas.style.display = "block";
        theProgram.destCanvas.width = theProgram.destCanvas.style.width = destData.width;
        theProgram.destCanvas.height = theProgram.destCanvas.style.height = destData.height;
        theProgram.destCanvas.style.width = theProgram.destCanvas.width + "px" ;
        theProgram.destCanvas.style.height = theProgram.destCanvas.height + "px";
        
        theProgram.destCTX.putImageData(destData, 0, 0);
    },
    
    
};  // end theProgram variable
    
// ----------------------------------------------------------------------------
//                                                          window.ONLOAD
// ----------------------------------------------------------------------------
window.onload = function()
{
    // Initialize and Start the game
    theProgram.Main();
    
};

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// end of file
